"use client";

import React, { useEffect, useState } from 'react';
import { Swiper, SwiperSlide } from 'swiper/react';
import 'swiper/css';
import 'swiper/css/pagination';
import 'swiper/css/navigation';
import { Pagination, Autoplay } from 'swiper/modules';
import { FaStar } from 'react-icons/fa';
import Link from 'next/link';
import { generateSlug } from "@/lib/generateSlug";

const TrendingMovieSlider: React.FC = () => {
  const [trendingMovies, setTrendingMovies] = useState<any[]>([]);

  useEffect(() => {
    const fetchTrendingMovies = async () => {
      try {
        const response = await fetch(
          `https://api.themoviedb.org/3/trending/movie/day?api_key=${process.env.NEXT_PUBLIC_TMDB_API_KEY}`
        );
        const data = await response.json();
        setTrendingMovies(data.results.slice(0, 20)); // Get the first 20 trending movies
      } catch (error) {
        console.error('Failed to fetch trending movies:', error);
      }
    };

    fetchTrendingMovies();
  }, []);

  return (
    <div className="relative mt-12 animate-fadeInUp">
      <div className="flex justify-between items-center mb-4 mx-4 animate-slideInLeft">
        <h2 className="text-2xl font-bold text-white text-left md:text-2xl sm:text-xl">
          Trending Movies
        </h2>
        <a href="/movies" className="text-red-500 text-sm md:text-lg hover:underline">
          See All
        </a>
      </div>
      <Swiper
        modules={[Pagination, Autoplay]}
        spaceBetween={5}
        slidesPerView={3} // Default for mobile
        breakpoints={{
          640: {
            slidesPerView: 3, // 3 slides per view on mobile
          },
          768: {
            slidesPerView: 5, // 5 slides per view on tablets
          },
          1024: {
            slidesPerView: 8, // 8 slides per view on PC
          },
        }}
        loop={true}
        autoplay={{ delay: 3000 }}
        pagination={{
          clickable: true,
          bulletClass: 'swiper-pagination-bullet',
          bulletActiveClass: 'swiper-pagination-bullet-active',
        }}
        className="mySwiper"
      >
        {trendingMovies.map((movie) => (
          <SwiperSlide key={movie.id}>
            <Link href={`/watch/movie/${generateSlug(movie.title, movie.id)}`}>
              <div className="relative p-1 cursor-pointer">
                <img
                  src={`https://image.tmdb.org/t/p/w500${movie.poster_path}`}
                  alt={movie.title}
                  className="w-full h-auto rounded-lg shadow-lg"
                />
                <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-yellow-400 text-xs px-2 py-1 rounded flex items-center">
                  <FaStar className="mr-1" />
                  {movie.vote_average.toFixed(1)}
                </div>
              </div>
            </Link>
          </SwiperSlide>
        ))}
      </Swiper>
      <div className="mt-4 custom-pagination swiper-pagination"></div>
      <style jsx global>{`
        .swiper-pagination {
          position: relative;
          margin-top: 10px;
        }
        .swiper-pagination-bullet {
          background-color: rgba(255, 255, 255, 0.4);
        }
        .swiper-pagination-bullet-active {
          background-color: red;
        }

        @keyframes fadeInUp {
          from {
            opacity: 0;
            transform: translateY(20px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes slideInLeft {
          from {
            opacity: 0;
            transform: translateX(-20px);
          }
          to {
            opacity: 1;
            transform: translateX(0);
          }
        }

        .animate-fadeInUp {
          animation: fadeInUp 1s ease-in-out;
        }

        .animate-slideInLeft {
          animation: slideInLeft 1s ease-in-out;
        }
      `}</style>
    </div>
  );
};

export default TrendingMovieSlider;
